@@ -4,7 +4,7 @@ from .math.brents_root_finding import find_root_brents
 from .math.krylov_exp import krylov_exp, DEFAULT_MAX_KRYLOV_DIM
 from .jump_lindblad_operators import compute_noise_from_lindbladians
 from .math.matmul import matmul_2x2_with_batched
-from .utils import get_max_rss, apply_measurement_errors, unix_like
+from .utils import get_max_rss, apply_measurement_errors, unix_like, init_logging
 
 __all__ = [
     "__version__",
@@ -19,6 +19,7 @@ __all__ = [
     "DEVICE_COUNT",
     "apply_measurement_errors",
     "unix_like",
+    "init_logging",
 ]
 
-__version__ = "2.4.0"
+__version__ = "2.5.2"
